package org.coderu.adapters.junit;

import java.util.Collection;
import java.util.Collections;

import org.coderu.adapters.junit.utils.String2TypeUtils;
import org.coderu.core.api.Depth;

public final class CoderuAssertAdapter {

    private final CoderuAssert junitTester;

    public CoderuAssertAdapter(final CoderuAssert junitTester) {
        this.junitTester = junitTester;
    }

    public void assertNoViolations(final Class<?> unit) { // NO_UCD

        assertNoViolations(unit, ROOT, Depth.UNLIMITED);
    }

    public void assertNoViolations( // NO_UCD
            final Class<?> unit, final String package2test) { // NO_UCD

        assertNoViolations(unit, package2test, Depth.UNLIMITED);
    }

    public void assertNoViolations( // NO_UCD
            final Class<?> unit, final String package2test, final Depth depth) { // NO_UCD

        assertNoViolations(Collections.<Class<?>> singletonList(unit),
                Collections.singletonList(package2test),
                Collections.<String> emptyList(), depth);
    }

    public void assertNoViolations(final Collection<Class<?>> units) { // NO_UCD

        assertNoViolations(units, Collections.singletonList(ROOT),
                Collections.<String> emptyList());
    }

    public void assertNoViolations( // NO_UCD
            final Collection<Class<?>> units, final String package2test) { // NO_UCD

        assertNoViolations(units, Collections.singletonList(package2test),
                Collections.<String> emptyList());
    }

    public void assertNoViolations( // NO_UCD
            final Class<?> units, final Collection<String> package2test) { // NO_UCD

        assertNoViolations(Collections.<Class<?>> singletonList(units),
                package2test, Collections.<String> emptyList());
    }

    public void assertNoViolations(
            // NO_UCD
            final Class<?> unit, final String package2test,
            final String package2excude) { // NO_UCD

        assertNoViolations(Collections.<Class<?>> singletonList(unit),
                Collections.singletonList(package2test),
                Collections.singletonList(package2excude));
    }

    public void assertNoViolations(
            // NO_UCD
            final Class<?> unit, final String package2test,
            final Collection<String> package2excude) { // NO_UCD

        assertNoViolations(Collections.<Class<?>> singletonList(unit),
                Collections.singletonList(package2test), package2excude);
    }

    public void assertNoViolations(
            // NO_UCD
            final Class<?> unit, final Collection<String> package2test,
            final Collection<String> package2excude) { // NO_UCD

        assertNoViolations(Collections.<Class<?>> singletonList(unit),
                package2test, package2excude);
    }

    public void assertNoViolations(
            // NO_UCD
            final Class<?> unit, final Collection<String> package2test,
            final Collection<String> package2excude, final Depth depth) { // NO_UCD

        assertNoViolations(Collections.<Class<?>> singletonList(unit),
                package2test, package2excude, depth);
    }

    public void assertNoViolations(
            // NO_UCD
            final Collection<Class<?>> unit,
            final Collection<String> package2test,
            final Collection<String> package2excude) {

        assertNoViolations(unit, package2test, package2excude, Depth.UNLIMITED);
    }

    public void assertNoViolations(
            // NO_UCD
            final Collection<Class<?>> unit,
            final Collection<String> package2test,
            final Collection<String> package2excude, final Depth depth) {

        junitTester.assertNoViolations(String2TypeUtils.toCompileUnit(unit),
                String2TypeUtils.toPackages(package2test),
                String2TypeUtils.toPackages(package2excude), depth);
    }

    private static final String ROOT = "";
}